@@ -17,16 +17,16 @@ import os
 import uuid
 
 import mock
-from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 
+import keystone.conf
 from keystone import exception
 from keystone import identity
 from keystone.tests import unit
 from keystone.tests.unit.ksfixtures import database
 
 
-CONF = cfg.CONF
+CONF = keystone.conf.CONF
 
 
 class TestDomainConfigs(unit.BaseTestCase):
@@ -164,8 +164,10 @@ class TestDatabaseDomainConfigs(unit.TestCase):
 
         # Now turn off using database domain configuration and check that the
         # default config file values are now seen instead of the overrides.
-        CONF.set_override('domain_configurations_from_database', False,
-                          'identity', enforce_type=True)
+        self.config_fixture.config(
+            group='identity',
+            domain_configurations_from_database=False)
+
         domain_config = identity.DomainConfigs()
         domain_config.setup_domain_drivers(fake_standard_driver,
                                            self.resource_api)
